@@ -130,3 +130,5 @@ def find_lib(libname):
             return True
     except:
         return -1
+def download_lib(lib):
+    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")
\ No newline at end of file
